@@ -1,6 +1,6 @@
 package AI::MicroStructure::MultiList;
 use strict;
-use AI::MicroStructure ();    # do not export metaname and friends
+use AI::MicroStructure ();    # do not export microname and friends
 use AI::MicroStructure::RemoteList;
 use List::Util qw( shuffle );
 use Carp;
@@ -32,16 +32,16 @@ sub init {
     }
 
     ${"$class\::Default"} = $data->{default} || ':all';
-    ${"$class\::Theme"} = ( split /::/, $class )[-1];
+    ${"$class\::structure"} = ( split /::/, $class )[-1];
 
     *{"$class\::import"} = sub {
         my $callpkg = caller(0);
-        my $theme   = ${"$class\::Theme"};
-        my $meta    = $class->new;
-        *{"$callpkg\::meta$theme"} = sub { $meta->name(@_) };
+        my $structure   = ${"$class\::structure"};
+        my $micro    = $class->new;
+        *{"$callpkg\::micro$structure"} = sub { $micro->name(@_) };
     };
 
-    ${"$class\::meta"} = $class->new();
+    ${"$class\::micro"} = $class->new();
 }
 
 sub name {
@@ -51,7 +51,7 @@ sub name {
     if ( !$class ) {    # called as a class method!
         $class = $self;
         no strict 'refs';
-        $self = ${"$class\::meta"};
+        $self = ${"$class\::micro"};
     }
 	no strict 'refs';
 
@@ -124,12 +124,14 @@ sub has_category {
     return exists ${"$class\::MultiList"}{$category};
 }
 
-sub theme {
+sub structure {
     my $class = ref $_[0] || $_[0];
     no strict 'refs';
-    return ${"$class\::Theme"};
+    return ${"$class\::structure"};
 }
 
+
+
 1;
 
 __END__
